# For Unicorn Engine. AUTO-GENERATED FILE, DO NOT EDIT [m68k_const.py]

# M68K CPU

UC_CPU_M68K_M5206 = 0
UC_CPU_M68K_M68000 = 1
UC_CPU_M68K_M68020 = 2
UC_CPU_M68K_M68030 = 3
UC_CPU_M68K_M68040 = 4
UC_CPU_M68K_M68060 = 5
UC_CPU_M68K_M5208 = 6
UC_CPU_M68K_CFV4E = 7
UC_CPU_M68K_ANY = 8
UC_CPU_M68K_ENDING = 9

# M68K registers

UC_M68K_REG_INVALID = 0
UC_M68K_REG_A0 = 1
UC_M68K_REG_A1 = 2
UC_M68K_REG_A2 = 3
UC_M68K_REG_A3 = 4
UC_M68K_REG_A4 = 5
UC_M68K_REG_A5 = 6
UC_M68K_REG_A6 = 7
UC_M68K_REG_A7 = 8
UC_M68K_REG_D0 = 9
UC_M68K_REG_D1 = 10
UC_M68K_REG_D2 = 11
UC_M68K_REG_D3 = 12
UC_M68K_REG_D4 = 13
UC_M68K_REG_D5 = 14
UC_M68K_REG_D6 = 15
UC_M68K_REG_D7 = 16
UC_M68K_REG_SR = 17
UC_M68K_REG_PC = 18
UC_M68K_REG_CR_SFC = 19
UC_M68K_REG_CR_DFC = 20
UC_M68K_REG_CR_VBR = 21
UC_M68K_REG_CR_CACR = 22
UC_M68K_REG_CR_TC = 23
UC_M68K_REG_CR_MMUSR = 24
UC_M68K_REG_CR_SRP = 25
UC_M68K_REG_CR_USP = 26
UC_M68K_REG_CR_MSP = 27
UC_M68K_REG_CR_ISP = 28
UC_M68K_REG_CR_URP = 29
UC_M68K_REG_CR_ITT0 = 30
UC_M68K_REG_CR_ITT1 = 31
UC_M68K_REG_CR_DTT0 = 32
UC_M68K_REG_CR_DTT1 = 33
UC_M68K_REG_ENDING = 34
